"""CATAPA Authentication Constants.

This module contains constants used for CATAPA API authentication.

Authors:
    Handrian Alandi (handrian.alandi@gdplabs.id)

References:
    NONE
"""

ONE_MINUTE_IN_SECONDS = 60
ONE_HOUR_IN_SECONDS = 3600

# Token expiration buffer in seconds (5 minutes)
TOKEN_EXPIRATION_BUFFER_SECONDS = 5 * ONE_MINUTE_IN_SECONDS
