# coding: utf-8

# flake8: noqa
"""
    CATAPA API

    # Introduction CATAPA API uses RESTful API style. It uses JSON data format for data exchange and utilizes HTTP verbs as appropriate.  For authorization & authentication, CATAPA API uses OAuth 2.0 protocol.  # Base URL Production: https://api.catapa.com  # Authentication Clients need to acquire an access token before they send HTTP requests to resource endpoints.  <SecurityDefinitions />  ## Validate Access Token    Use this endpoint to verify if an access token is valid and was issued by the API gateway. The endpoint supports both user tokens and client credentials tokens.    | **HTTP Method**  | `GET`                                                |                                         |   |------------------|------------------------------------------------------|-----------------------------------------|   | **URL**          | `<base-url>/v1/oauth-clients/validate-access-token`  |                                         |   | **Headers**      | `Authorization`                                      | `Bearer <access-token>`                 |   |                  | `Tenant`                                             | Your tenant identifier (e.g., \"catapa\") |  ### Example request using `curl`    ```bash   curl --location '<base-url>/v1/oauth-clients/validate-access-token' \\     --header 'Tenant: catapa' \\     --header 'Authorization: Bearer <access-token>'   ```  ### Response codes  - **200 OK**: Token is valid - **401 Unauthorized**: Token is invalid or expired  ### Notes  - This endpoint validates both user authentication tokens and client credentials tokens - For server-to-server communication, use client credentials flow with the token in the Authorization header - No response body is returned; the status code indicates the validation result - The `Tenant` header is required to specify which tenant context to validate the token against  # HTTP Headers Each request should contain the following headers.  |Headers        |Description  | |---------------|-------------| |Tenant         |Tenant name. e.g. Catapa| |Authorization  |For authentication. Value format: Bearer <access-token>|  Example HTTP Request using cURL: ```bash curl <base-url>/core/v1/employees?page=0&size=10 \\ -H \"Tenant: <tenant name>\" \\ -H \"Authorization: Bearer <access-token>\" ```  # Rate Limit To ensure optimal API performance and fair usage for all users, we implement rate limiting. The general limit is **400 requests per minute, per Client ID**. If you exceed the rate limit, you will receive an HTTP 429 (Too Many Requests) error response.  # Pagination The API provides `page` & `size` query params. `page` is a page number starting from 0. `size` is number of elements per page. Maximum value of `size` is 50.  Every paginated endpoints will have following response format: ``` {   \"content\": [     { ... },     { ... }   ],   \"number\": 0, // page number   \"size\": 10, // page size   \"numberOfElements\": 10, // number of element in this current page   \"totalElements\": 100,   \"totalPages\": 10 } ```  # Search Query You can perform search operations in some endpoints by setting the query parameter. Query value parameter constructed with following format:  ```bash ?query=<key><operator><value>,<key><operator><value> ```  Explanations: | Format | Descriptions | |-|-| | `<key>` | Key name to search certain fields | | `<operator>`   | Operation to apply on certain fields.<br>Supported operators: `:` `<` `>` | | `<value>` | Value to apply on search. **Value should be encoded using URL encoder**. For examples:<br><br>Plain: `John Doe`<br>Encoded: `John%20Doe` | | `,` | AND operator |   For example, the `/core/v1/employees` endpoint has following search query. |Key                    |Supported Operators  |Notes  | |-----------------------|---------------------|-------| |identificationNumberIn | `:`                 |Equal operator with multiple values. Each value should separated with delimiters `;`| |name                   | `:`                 |Like operator| |startDate              | `:`<br/>`>`<br/>`<` |Equal<br>Greater than or equal to<br>Less than or equal to|  Clients can construct search query with these following variations:  1. Search an employee with ID number 1111 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111 ``` 1. Search multiple employees with ID number 1111 and 2222 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111;2222 ``` 1. Search employees with name `John Doe` ```bash curl <base-url>/core/v1/employees?query=name:John%20Doe ``` 1. Search all employees with start date between 2020-01-01 and 2020-12-31: ```bash curl <base-url>/core/v1/employees?query=startDate>2020-01-01,startDate<2020-12-31 ``` 

    The version of the OpenAPI document: 1.0.0
    Contact: support@catapa.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from openapi_client.models.additional_assignment_approval_page_response import AdditionalAssignmentApprovalPageResponse
from openapi_client.models.additional_assignment_approval_response import AdditionalAssignmentApprovalResponse
from openapi_client.models.additional_assignment_approvale_sub_location_response import AdditionalAssignmentApprovaleSubLocationResponse
from openapi_client.models.additional_assignment_response import AdditionalAssignmentResponse
from openapi_client.models.additional_family_membership_response import AdditionalFamilyMembershipResponse
from openapi_client.models.additional_income_payment_list_item_response import AdditionalIncomePaymentListItemResponse
from openapi_client.models.additional_income_payment_page_response import AdditionalIncomePaymentPageResponse
from openapi_client.models.address_detail_response import AddressDetailResponse
from openapi_client.models.amount_request import AmountRequest
from openapi_client.models.analytics_chart_data_response import AnalyticsChartDataResponse
from openapi_client.models.analytics_chart_data_series_response import AnalyticsChartDataSeriesResponse
from openapi_client.models.analytics_chart_page_response import AnalyticsChartPageResponse
from openapi_client.models.analytics_chart_request import AnalyticsChartRequest
from openapi_client.models.analytics_chart_response import AnalyticsChartResponse
from openapi_client.models.analytics_color_scheme_detail_response import AnalyticsColorSchemeDetailResponse
from openapi_client.models.analytics_color_scheme_response import AnalyticsColorSchemeResponse
from openapi_client.models.analytics_column_response import AnalyticsColumnResponse
from openapi_client.models.annual_tax_calculation_simulator_monthly_tax_reports_response import AnnualTaxCalculationSimulatorMonthlyTaxReportsResponse
from openapi_client.models.annual_tax_calculation_simulator_request import AnnualTaxCalculationSimulatorRequest
from openapi_client.models.annual_tax_calculation_simulator_response import AnnualTaxCalculationSimulatorResponse
from openapi_client.models.annual_tax_calculation_simulator_result_response import AnnualTaxCalculationSimulatorResultResponse
from openapi_client.models.anomaly_suspect_attribute_response import AnomalySuspectAttributeResponse
from openapi_client.models.anomaly_suspect_attribute_value_child_response import AnomalySuspectAttributeValueChildResponse
from openapi_client.models.anomaly_suspect_attribute_value_response import AnomalySuspectAttributeValueResponse
from openapi_client.models.anomaly_suspect_file_response import AnomalySuspectFileResponse
from openapi_client.models.anomaly_suspect_page_response import AnomalySuspectPageResponse
from openapi_client.models.anomaly_suspect_response import AnomalySuspectResponse
from openapi_client.models.attendance_item_response import AttendanceItemResponse
from openapi_client.models.attendance_page_response import AttendancePageResponse
from openapi_client.models.attendance_recapitulation_detail_attendance_item_response import AttendanceRecapitulationDetailAttendanceItemResponse
from openapi_client.models.attendance_recapitulation_detail_item_response import AttendanceRecapitulationDetailItemResponse
from openapi_client.models.attendance_recapitulation_detail_overtime_response import AttendanceRecapitulationDetailOvertimeResponse
from openapi_client.models.attendance_recapitulation_detail_page_response import AttendanceRecapitulationDetailPageResponse
from openapi_client.models.attendance_status_response import AttendanceStatusResponse
from openapi_client.models.authority_detail_response import AuthorityDetailResponse
from openapi_client.models.bank_account_configuration_page_response import BankAccountConfigurationPageResponse
from openapi_client.models.bank_account_configuration_request import BankAccountConfigurationRequest
from openapi_client.models.bank_account_configuration_response import BankAccountConfigurationResponse
from openapi_client.models.bank_account_configuration_response_source import BankAccountConfigurationResponseSource
from openapi_client.models.bank_account_response import BankAccountResponse
from openapi_client.models.bank_branch_page_response import BankBranchPageResponse
from openapi_client.models.bank_branch_response import BankBranchResponse
from openapi_client.models.bank_branch_simple_response import BankBranchSimpleResponse
from openapi_client.models.bank_page_response import BankPageResponse
from openapi_client.models.bank_response import BankResponse
from openapi_client.models.bpjs_healthcare_current_month_detail_response import BpjsHealthcareCurrentMonthDetailResponse
from openapi_client.models.bpjs_healthcare_membership_additional_family_membership import BpjsHealthcareMembershipAdditionalFamilyMembership
from openapi_client.models.bpjs_healthcare_membership_request import BpjsHealthcareMembershipRequest
from openapi_client.models.bpjs_healthcare_membership_response import BpjsHealthcareMembershipResponse
from openapi_client.models.bpjs_healthcare_premium_details_item_response import BpjsHealthcarePremiumDetailsItemResponse
from openapi_client.models.bpjs_healthcare_premium_details_response import BpjsHealthcarePremiumDetailsResponse
from openapi_client.models.bpjs_healthcare_premium_summary_list_item_response import BpjsHealthcarePremiumSummaryListItemResponse
from openapi_client.models.bpjs_healthcare_premium_summary_page_response import BpjsHealthcarePremiumSummaryPageResponse
from openapi_client.models.bpjs_healthcare_provider_list_item_response import BpjsHealthcareProviderListItemResponse
from openapi_client.models.bpjs_healthcare_provider_page_response import BpjsHealthcareProviderPageResponse
from openapi_client.models.bpjs_healthcare_template_list_item_response import BpjsHealthcareTemplateListItemResponse
from openapi_client.models.bpjs_healthcare_template_page_response import BpjsHealthcareTemplatePageResponse
from openapi_client.models.bpjs_healthcare_treatment_class_response import BpjsHealthcareTreatmentClassResponse
from openapi_client.models.bpjs_manpower_current_month_detail_response import BpjsManpowerCurrentMonthDetailResponse
from openapi_client.models.bpjs_manpower_membership_request import BpjsManpowerMembershipRequest
from openapi_client.models.bpjs_manpower_membership_response import BpjsManpowerMembershipResponse
from openapi_client.models.bpjs_manpower_premium_details_item_response import BpjsManpowerPremiumDetailsItemResponse
from openapi_client.models.bpjs_manpower_premium_details_response import BpjsManpowerPremiumDetailsResponse
from openapi_client.models.bpjs_manpower_premium_summary_list_item_response import BpjsManpowerPremiumSummaryListItemResponse
from openapi_client.models.bpjs_manpower_premium_summary_page_response import BpjsManpowerPremiumSummaryPageResponse
from openapi_client.models.bpjs_manpower_provider_page_response import BpjsManpowerProviderPageResponse
from openapi_client.models.bpjs_manpower_provider_response import BpjsManpowerProviderResponse
from openapi_client.models.bpjs_manpower_template_page_response import BpjsManpowerTemplatePageResponse
from openapi_client.models.bpjs_manpower_template_response import BpjsManpowerTemplateResponse
from openapi_client.models.bulk_operation_failure_param_response import BulkOperationFailureParamResponse
from openapi_client.models.bulk_operation_failure_response import BulkOperationFailureResponse
from openapi_client.models.bulk_operation_response import BulkOperationResponse
from openapi_client.models.calculation_scenario_component import CalculationScenarioComponent
from openapi_client.models.calculation_scenario_previous_job_component import CalculationScenarioPreviousJobComponent
from openapi_client.models.calculation_scenario_salary_component import CalculationScenarioSalaryComponent
from openapi_client.models.chart_filter_request import ChartFilterRequest
from openapi_client.models.chart_filter_response import ChartFilterResponse
from openapi_client.models.chart_table_relation_request import ChartTableRelationRequest
from openapi_client.models.chart_table_relation_response import ChartTableRelationResponse
from openapi_client.models.chart_value_collection_filter_request import ChartValueCollectionFilterRequest
from openapi_client.models.city_page_response import CityPageResponse
from openapi_client.models.city_response import CityResponse
from openapi_client.models.company_bank_account_page_response import CompanyBankAccountPageResponse
from openapi_client.models.company_bank_account_response import CompanyBankAccountResponse
from openapi_client.models.company_detail_request import CompanyDetailRequest
from openapi_client.models.company_detail_response import CompanyDetailResponse
from openapi_client.models.company_detail_time_zone_request import CompanyDetailTimeZoneRequest
from openapi_client.models.company_group_page_response import CompanyGroupPageResponse
from openapi_client.models.company_list_item_response import CompanyListItemResponse
from openapi_client.models.company_page_response import CompanyPageResponse
from openapi_client.models.company_superior_response import CompanySuperiorResponse
from openapi_client.models.contact_information_page_response import ContactInformationPageResponse
from openapi_client.models.contact_information_request import ContactInformationRequest
from openapi_client.models.contact_information_response import ContactInformationResponse
from openapi_client.models.cost_center_list_item_response import CostCenterListItemResponse
from openapi_client.models.cost_center_page_response import CostCenterPageResponse
from openapi_client.models.cost_center_request import CostCenterRequest
from openapi_client.models.cost_center_response import CostCenterResponse
from openapi_client.models.cost_center_simple_response import CostCenterSimpleResponse
from openapi_client.models.count_response import CountResponse
from openapi_client.models.country_page_response import CountryPageResponse
from openapi_client.models.country_request import CountryRequest
from openapi_client.models.country_response import CountryResponse
from openapi_client.models.create_city_request import CreateCityRequest
from openapi_client.models.create_city_request_state import CreateCityRequestState
from openapi_client.models.currency_page_response import CurrencyPageResponse
from openapi_client.models.currency_response import CurrencyResponse
from openapi_client.models.currency_simple_response import CurrencySimpleResponse
from openapi_client.models.custom_table_column_response import CustomTableColumnResponse
from openapi_client.models.custom_table_entry_page_response import CustomTableEntryPageResponse
from openapi_client.models.custom_table_page_response import CustomTablePageResponse
from openapi_client.models.custom_table_response import CustomTableResponse
from openapi_client.models.editable_salary_preprocess_request import EditableSalaryPreprocessRequest
from openapi_client.models.editable_salary_preprocess_response import EditableSalaryPreprocessResponse
from openapi_client.models.editable_salary_preprocess_success import EditableSalaryPreprocessSuccess
from openapi_client.models.education_level_page_response import EducationLevelPageResponse
from openapi_client.models.education_level_response import EducationLevelResponse
from openapi_client.models.education_page_response import EducationPageResponse
from openapi_client.models.education_response import EducationResponse
from openapi_client.models.emergency_contact_response import EmergencyContactResponse
from openapi_client.models.employee_create_response import EmployeeCreateResponse
from openapi_client.models.employee_detail_page_response import EmployeeDetailPageResponse
from openapi_client.models.employee_detail_request import EmployeeDetailRequest
from openapi_client.models.employee_detail_response import EmployeeDetailResponse
from openapi_client.models.employee_full_response import EmployeeFullResponse
from openapi_client.models.employee_hiring_data_request import EmployeeHiringDataRequest
from openapi_client.models.employee_hiring_data_response import EmployeeHiringDataResponse
from openapi_client.models.employee_hiring_data_simple_response import EmployeeHiringDataSimpleResponse
from openapi_client.models.employee_id_identification_number_response import EmployeeIdIdentificationNumberResponse
from openapi_client.models.employee_id_name_response import EmployeeIdNameResponse
from openapi_client.models.employee_identification_number_response import EmployeeIdentificationNumberResponse
from openapi_client.models.employee_identity_card_page_response import EmployeeIdentityCardPageResponse
from openapi_client.models.employee_identity_card_request import EmployeeIdentityCardRequest
from openapi_client.models.employee_identity_card_response import EmployeeIdentityCardResponse
from openapi_client.models.employee_manager_response import EmployeeManagerResponse
from openapi_client.models.employee_page_response import EmployeePageResponse
from openapi_client.models.employee_paygroup_page_response import EmployeePaygroupPageResponse
from openapi_client.models.employee_paygroup_response import EmployeePaygroupResponse
from openapi_client.models.employee_request import EmployeeRequest
from openapi_client.models.employee_response import EmployeeResponse
from openapi_client.models.employee_salary_request import EmployeeSalaryRequest
from openapi_client.models.employee_salary_response import EmployeeSalaryResponse
from openapi_client.models.employee_salary_template_page_response import EmployeeSalaryTemplatePageResponse
from openapi_client.models.employee_salary_template_request import EmployeeSalaryTemplateRequest
from openapi_client.models.employee_salary_template_response import EmployeeSalaryTemplateResponse
from openapi_client.models.employee_salary_template_update_response import EmployeeSalaryTemplateUpdateResponse
from openapi_client.models.employee_simple_response import EmployeeSimpleResponse
from openapi_client.models.employee_variable_metadata_page_response import EmployeeVariableMetadataPageResponse
from openapi_client.models.employee_variable_metadata_request import EmployeeVariableMetadataRequest
from openapi_client.models.employee_variable_metadata_response import EmployeeVariableMetadataResponse
from openapi_client.models.employee_variable_page_response import EmployeeVariablePageResponse
from openapi_client.models.employee_variable_request import EmployeeVariableRequest
from openapi_client.models.employee_variable_response import EmployeeVariableResponse
from openapi_client.models.employee_variable_validation_request import EmployeeVariableValidationRequest
from openapi_client.models.employee_variable_validation_response import EmployeeVariableValidationResponse
from openapi_client.models.employee_workday_configuration_page_response import EmployeeWorkdayConfigurationPageResponse
from openapi_client.models.employee_workday_configuration_request import EmployeeWorkdayConfigurationRequest
from openapi_client.models.employee_workday_configuration_response import EmployeeWorkdayConfigurationResponse
from openapi_client.models.employment_data_position_response import EmploymentDataPositionResponse
from openapi_client.models.employment_data_request import EmploymentDataRequest
from openapi_client.models.employment_data_response import EmploymentDataResponse
from openapi_client.models.employment_status_detail_position_response import EmploymentStatusDetailPositionResponse
from openapi_client.models.employment_status_detail_response import EmploymentStatusDetailResponse
from openapi_client.models.employment_status_history_detail_response import EmploymentStatusHistoryDetailResponse
from openapi_client.models.employment_status_history_page_response import EmploymentStatusHistoryPageResponse
from openapi_client.models.employment_status_page_response import EmploymentStatusPageResponse
from openapi_client.models.employment_status_type_page_response import EmploymentStatusTypePageResponse
from openapi_client.models.employment_status_type_response import EmploymentStatusTypeResponse
from openapi_client.models.employment_type_page_response import EmploymentTypePageResponse
from openapi_client.models.employment_type_request import EmploymentTypeRequest
from openapi_client.models.employment_type_response import EmploymentTypeResponse
from openapi_client.models.error_response import ErrorResponse
from openapi_client.models.family_approval_list_item_response import FamilyApprovalListItemResponse
from openapi_client.models.family_approval_list_item_with_approval_status_response import FamilyApprovalListItemWithApprovalStatusResponse
from openapi_client.models.family_approval_page_response import FamilyApprovalPageResponse
from openapi_client.models.family_approval_request import FamilyApprovalRequest
from openapi_client.models.family_approval_response import FamilyApprovalResponse
from openapi_client.models.family_historical_page_response import FamilyHistoricalPageResponse
from openapi_client.models.family_historical_response import FamilyHistoricalResponse
from openapi_client.models.family_member_relation_page_response import FamilyMemberRelationPageResponse
from openapi_client.models.family_member_relation_response import FamilyMemberRelationResponse
from openapi_client.models.field_of_study_page_response import FieldOfStudyPageResponse
from openapi_client.models.field_of_study_response import FieldOfStudyResponse
from openapi_client.models.fingerprint_failure_item_response import FingerprintFailureItemResponse
from openapi_client.models.fingerprint_item_request import FingerprintItemRequest
from openapi_client.models.fingerprint_response import FingerprintResponse
from openapi_client.models.fingerprint_success_item_response import FingerprintSuccessItemResponse
from openapi_client.models.former_employee_income_employee_amount_update_request import FormerEmployeeIncomeEmployeeAmountUpdateRequest
from openapi_client.models.former_employee_income_employee_page_response import FormerEmployeeIncomeEmployeePageResponse
from openapi_client.models.former_employee_income_employee_response import FormerEmployeeIncomeEmployeeResponse
from openapi_client.models.former_employee_income_page_response import FormerEmployeeIncomePageResponse
from openapi_client.models.former_employee_income_response import FormerEmployeeIncomeResponse
from openapi_client.models.holiday_item_response import HolidayItemResponse
from openapi_client.models.holiday_page_response import HolidayPageResponse
from openapi_client.models.id_code_name_response import IdCodeNameResponse
from openapi_client.models.id_request import IdRequest
from openapi_client.models.id_response import IdResponse
from openapi_client.models.identity_card_page_response import IdentityCardPageResponse
from openapi_client.models.identity_card_response import IdentityCardResponse
from openapi_client.models.institution_page_response import InstitutionPageResponse
from openapi_client.models.institution_response import InstitutionResponse
from openapi_client.models.job_level_page_response import JobLevelPageResponse
from openapi_client.models.job_level_request import JobLevelRequest
from openapi_client.models.job_level_response import JobLevelResponse
from openapi_client.models.job_title_level_mapping_page_response import JobTitleLevelMappingPageResponse
from openapi_client.models.job_title_level_mapping_response import JobTitleLevelMappingResponse
from openapi_client.models.job_title_page_response import JobTitlePageResponse
from openapi_client.models.job_title_request import JobTitleRequest
from openapi_client.models.job_title_request_deprecated import JobTitleRequestDeprecated
from openapi_client.models.job_title_response import JobTitleResponse
from openapi_client.models.job_title_with_job_levels_response import JobTitleWithJobLevelsResponse
from openapi_client.models.kpp_page_response import KppPageResponse
from openapi_client.models.kpp_response import KppResponse
from openapi_client.models.kpp_simple_response import KppSimpleResponse
from openapi_client.models.leave_balance_item_response import LeaveBalanceItemResponse
from openapi_client.models.leave_balance_page_response import LeaveBalancePageResponse
from openapi_client.models.leave_balance_request import LeaveBalanceRequest
from openapi_client.models.location_create_request import LocationCreateRequest
from openapi_client.models.location_group_page_response import LocationGroupPageResponse
from openapi_client.models.location_page_response import LocationPageResponse
from openapi_client.models.location_response import LocationResponse
from openapi_client.models.logo_file_metadata_response import LogoFileMetadataResponse
from openapi_client.models.manager_request import ManagerRequest
from openapi_client.models.monthly_recapitulation_item_detail_response import MonthlyRecapitulationItemDetailResponse
from openapi_client.models.monthly_recapitulation_item_response import MonthlyRecapitulationItemResponse
from openapi_client.models.monthly_recapitulation_page_response import MonthlyRecapitulationPageResponse
from openapi_client.models.monthly_tax_calculation_simulator_request import MonthlyTaxCalculationSimulatorRequest
from openapi_client.models.monthly_tax_calculation_simulator_response import MonthlyTaxCalculationSimulatorResponse
from openapi_client.models.monthly_tax_detail_page_response import MonthlyTaxDetailPageResponse
from openapi_client.models.monthly_tax_detail_response import MonthlyTaxDetailResponse
from openapi_client.models.monthly_tax_report_page_response import MonthlyTaxReportPageResponse
from openapi_client.models.monthly_tax_report_response import MonthlyTaxReportResponse
from openapi_client.models.name_response import NameResponse
from openapi_client.models.non_employee_monthly_tax_calculation_simulator_response import NonEmployeeMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.o_auth_client_page_response import OAuthClientPageResponse
from openapi_client.models.o_auth_client_response import OAuthClientResponse
from openapi_client.models.operational_group_page_response import OperationalGroupPageResponse
from openapi_client.models.organization_group_page_response import OrganizationGroupPageResponse
from openapi_client.models.organization_group_request import OrganizationGroupRequest
from openapi_client.models.organization_head_page_response import OrganizationHeadPageResponse
from openapi_client.models.organization_head_response import OrganizationHeadResponse
from openapi_client.models.organization_hierarchy_page_response import OrganizationHierarchyPageResponse
from openapi_client.models.organization_hierarchy_request import OrganizationHierarchyRequest
from openapi_client.models.organization_hierarchy_response import OrganizationHierarchyResponse
from openapi_client.models.organization_history_hierarchy_response import OrganizationHistoryHierarchyResponse
from openapi_client.models.organization_history_page_response import OrganizationHistoryPageResponse
from openapi_client.models.organization_history_response import OrganizationHistoryResponse
from openapi_client.models.organization_page_response import OrganizationPageResponse
from openapi_client.models.organization_parent_response import OrganizationParentResponse
from openapi_client.models.organization_request import OrganizationRequest
from openapi_client.models.organization_response import OrganizationResponse
from openapi_client.models.organization_superior_page_response import OrganizationSuperiorPageResponse
from openapi_client.models.organization_superior_response import OrganizationSuperiorResponse
from openapi_client.models.other_leave_balance_create_response import OtherLeaveBalanceCreateResponse
from openapi_client.models.other_leave_balance_item_response import OtherLeaveBalanceItemResponse
from openapi_client.models.other_leave_balance_page_response import OtherLeaveBalancePageResponse
from openapi_client.models.other_leave_balance_request import OtherLeaveBalanceRequest
from openapi_client.models.other_leave_status_response import OtherLeaveStatusResponse
from openapi_client.models.page import Page
from openapi_client.models.paygroup_page_response import PaygroupPageResponse
from openapi_client.models.paygroup_response import PaygroupResponse
from openapi_client.models.payment_item_detail_response import PaymentItemDetailResponse
from openapi_client.models.payment_item_detail_salary_item_response import PaymentItemDetailSalaryItemResponse
from openapi_client.models.payment_item_group_last_sequence_response import PaymentItemGroupLastSequenceResponse
from openapi_client.models.payment_item_group_page_response import PaymentItemGroupPageResponse
from openapi_client.models.payment_item_group_response import PaymentItemGroupResponse
from openapi_client.models.payment_item_group_sequence_response import PaymentItemGroupSequenceResponse
from openapi_client.models.payroll_process_snapshot_bank_account_configuration_response import PayrollProcessSnapshotBankAccountConfigurationResponse
from openapi_client.models.payroll_process_snapshot_bank_account_response import PayrollProcessSnapshotBankAccountResponse
from openapi_client.models.payroll_process_snapshot_employment_status_response import PayrollProcessSnapshotEmploymentStatusResponse
from openapi_client.models.payroll_process_snapshot_page_response import PayrollProcessSnapshotPageResponse
from openapi_client.models.payroll_process_snapshot_response import PayrollProcessSnapshotResponse
from openapi_client.models.payroll_process_snapshot_workflow_activity_response import PayrollProcessSnapshotWorkflowActivityResponse
from openapi_client.models.payroll_process_snapshot_workflow_reason_response import PayrollProcessSnapshotWorkflowReasonResponse
from openapi_client.models.payroll_process_snapshot_workflow_template_response import PayrollProcessSnapshotWorkflowTemplateResponse
from openapi_client.models.payslip_additional_note_page_response import PayslipAdditionalNotePageResponse
from openapi_client.models.payslip_additional_note_request import PayslipAdditionalNoteRequest
from openapi_client.models.payslip_additional_note_response import PayslipAdditionalNoteResponse
from openapi_client.models.payslip_download_request import PayslipDownloadRequest
from openapi_client.models.payslip_layout_page_response import PayslipLayoutPageResponse
from openapi_client.models.payslip_layout_request import PayslipLayoutRequest
from openapi_client.models.payslip_layout_response import PayslipLayoutResponse
from openapi_client.models.permanent_monthly_tax_calculation_simulator_response import PermanentMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.photo_response import PhotoResponse
from openapi_client.models.place_of_birth_request import PlaceOfBirthRequest
from openapi_client.models.place_of_birth_response import PlaceOfBirthResponse
from openapi_client.models.point_of_hire_response import PointOfHireResponse
from openapi_client.models.position_cost_center_page_response import PositionCostCenterPageResponse
from openapi_client.models.position_cost_center_response import PositionCostCenterResponse
from openapi_client.models.position_history_organization_response import PositionHistoryOrganizationResponse
from openapi_client.models.position_history_page_response import PositionHistoryPageResponse
from openapi_client.models.position_history_response import PositionHistoryResponse
from openapi_client.models.position_list_item_response import PositionListItemResponse
from openapi_client.models.position_page_response import PositionPageResponse
from openapi_client.models.position_response import PositionResponse
from openapi_client.models.position_vacancy_status_page_response import PositionVacancyStatusPageResponse
from openapi_client.models.position_vacancy_status_response import PositionVacancyStatusResponse
from openapi_client.models.pph21_policy_response import Pph21PolicyResponse
from openapi_client.models.processable_time_allowance_transition_employee_response import ProcessableTimeAllowanceTransitionEmployeeResponse
from openapi_client.models.processable_time_allowance_transition_employment_status_response import ProcessableTimeAllowanceTransitionEmploymentStatusResponse
from openapi_client.models.processable_time_allowance_transition_page_response import ProcessableTimeAllowanceTransitionPageResponse
from openapi_client.models.processable_time_allowance_transition_response import ProcessableTimeAllowanceTransitionResponse
from openapi_client.models.processed_salary_payment_detail_response import ProcessedSalaryPaymentDetailResponse
from openapi_client.models.processed_salary_payment_page_response import ProcessedSalaryPaymentPageResponse
from openapi_client.models.processed_salary_payment_response import ProcessedSalaryPaymentResponse
from openapi_client.models.processed_transition_calculation_page_response import ProcessedTransitionCalculationPageResponse
from openapi_client.models.processed_transition_calculation_response import ProcessedTransitionCalculationResponse
from openapi_client.models.prorate_detail_response import ProrateDetailResponse
from openapi_client.models.prorate_detail_salary_template_detail_response import ProrateDetailSalaryTemplateDetailResponse
from openapi_client.models.prorate_detail_salary_template_detail_salary_item_response import ProrateDetailSalaryTemplateDetailSalaryItemResponse
from openapi_client.models.ptkp_category_page_response import PtkpCategoryPageResponse
from openapi_client.models.ptkp_category_response import PtkpCategoryResponse
from openapi_client.models.recurring_configuration_request import RecurringConfigurationRequest
from openapi_client.models.recurring_configuration_response import RecurringConfigurationResponse
from openapi_client.models.recurring_period_end_request import RecurringPeriodEndRequest
from openapi_client.models.recurring_period_end_response import RecurringPeriodEndResponse
from openapi_client.models.reject_approval_request import RejectApprovalRequest
from openapi_client.models.religion_page_response import ReligionPageResponse
from openapi_client.models.religion_request import ReligionRequest
from openapi_client.models.religion_response import ReligionResponse
from openapi_client.models.role_authority_page_response import RoleAuthorityPageResponse
from openapi_client.models.role_authority_response import RoleAuthorityResponse
from openapi_client.models.role_detail_response import RoleDetailResponse
from openapi_client.models.role_id_name_response import RoleIdNameResponse
from openapi_client.models.role_page_response import RolePageResponse
from openapi_client.models.role_permission_page_response import RolePermissionPageResponse
from openapi_client.models.role_permission_response import RolePermissionResponse
from openapi_client.models.role_response import RoleResponse
from openapi_client.models.salary_calculation_detail_page_response import SalaryCalculationDetailPageResponse
from openapi_client.models.salary_calculation_detail_response import SalaryCalculationDetailResponse
from openapi_client.models.salary_calculation_page_response import SalaryCalculationPageResponse
from openapi_client.models.salary_calculation_response import SalaryCalculationResponse
from openapi_client.models.salary_item_add_on_employee_request import SalaryItemAddOnEmployeeRequest
from openapi_client.models.salary_item_add_on_employee_response import SalaryItemAddOnEmployeeResponse
from openapi_client.models.salary_item_add_on_request import SalaryItemAddOnRequest
from openapi_client.models.salary_item_add_on_response import SalaryItemAddOnResponse
from openapi_client.models.salary_item_add_on_salary_item_request import SalaryItemAddOnSalaryItemRequest
from openapi_client.models.salary_item_page_response import SalaryItemPageResponse
from openapi_client.models.salary_item_response import SalaryItemResponse
from openapi_client.models.salary_item_response_with_category import SalaryItemResponseWithCategory
from openapi_client.models.salary_item_simple_response import SalaryItemSimpleResponse
from openapi_client.models.salary_item_with_salary_item_type_response import SalaryItemWithSalaryItemTypeResponse
from openapi_client.models.salary_payment_detail_company_bank_account_response import SalaryPaymentDetailCompanyBankAccountResponse
from openapi_client.models.salary_payment_detail_response import SalaryPaymentDetailResponse
from openapi_client.models.salary_payment_employee_response import SalaryPaymentEmployeeResponse
from openapi_client.models.salary_payment_employment_status_response import SalaryPaymentEmploymentStatusResponse
from openapi_client.models.salary_payment_page_response import SalaryPaymentPageResponse
from openapi_client.models.salary_payment_response import SalaryPaymentResponse
from openapi_client.models.salary_payment_summary_company_bank_account_response import SalaryPaymentSummaryCompanyBankAccountResponse
from openapi_client.models.salary_payment_summary_page_response import SalaryPaymentSummaryPageResponse
from openapi_client.models.salary_payment_summary_response import SalaryPaymentSummaryResponse
from openapi_client.models.salary_template_detail_response import SalaryTemplateDetailResponse
from openapi_client.models.salary_template_page_response import SalaryTemplatePageResponse
from openapi_client.models.salary_template_response import SalaryTemplateResponse
from openapi_client.models.severance_payment_plan_page_response import SeverancePaymentPlanPageResponse
from openapi_client.models.severance_payment_plan_response import SeverancePaymentPlanResponse
from openapi_client.models.severance_plan_detail_item_request import SeverancePlanDetailItemRequest
from openapi_client.models.severance_plan_detail_response import SeverancePlanDetailResponse
from openapi_client.models.severance_plan_page_response import SeverancePlanPageResponse
from openapi_client.models.severance_plan_payment_plan_item_request import SeverancePlanPaymentPlanItemRequest
from openapi_client.models.severance_plan_request import SeverancePlanRequest
from openapi_client.models.severance_plan_response import SeverancePlanResponse
from openapi_client.models.severance_plan_response_with_detail import SeverancePlanResponseWithDetail
from openapi_client.models.shift_pattern_template_detail_item_request import ShiftPatternTemplateDetailItemRequest
from openapi_client.models.shift_pattern_template_detail_item_request_shift import ShiftPatternTemplateDetailItemRequestShift
from openapi_client.models.shift_pattern_template_detail_response import ShiftPatternTemplateDetailResponse
from openapi_client.models.shift_pattern_template_item_response import ShiftPatternTemplateItemResponse
from openapi_client.models.shift_pattern_template_list_item_response import ShiftPatternTemplateListItemResponse
from openapi_client.models.shift_pattern_template_page_response import ShiftPatternTemplatePageResponse
from openapi_client.models.shift_pattern_template_request import ShiftPatternTemplateRequest
from openapi_client.models.shift_pattern_template_simple_response import ShiftPatternTemplateSimpleResponse
from openapi_client.models.shift_response import ShiftResponse
from openapi_client.models.sort_property import SortProperty
from openapi_client.models.state_list_item_response import StateListItemResponse
from openapi_client.models.state_page_response import StatePageResponse
from openapi_client.models.state_request import StateRequest
from openapi_client.models.state_response import StateResponse
from openapi_client.models.sub_location_location_response import SubLocationLocationResponse
from openapi_client.models.sub_location_page_response import SubLocationPageResponse
from openapi_client.models.sub_location_request import SubLocationRequest
from openapi_client.models.sub_location_response import SubLocationResponse
from openapi_client.models.tax_amount_response import TaxAmountResponse
from openapi_client.models.tax_and_allowance_response import TaxAndAllowanceResponse
from openapi_client.models.tax_calculation_detail_response import TaxCalculationDetailResponse
from openapi_client.models.tax_calculation_income_request import TaxCalculationIncomeRequest
from openapi_client.models.tax_calculation_page_response import TaxCalculationPageResponse
from openapi_client.models.tax_calculation_request import TaxCalculationRequest
from openapi_client.models.tax_calculation_response import TaxCalculationResponse
from openapi_client.models.tax_dependent_request import TaxDependentRequest
from openapi_client.models.tax_dependent_response import TaxDependentResponse
from openapi_client.models.tax_income_response import TaxIncomeResponse
from openapi_client.models.tax_membership_history_response import TaxMembershipHistoryResponse
from openapi_client.models.tax_membership_period_response import TaxMembershipPeriodResponse
from openapi_client.models.tax_membership_response import TaxMembershipResponse
from openapi_client.models.tax_membership_tax_subject_request import TaxMembershipTaxSubjectRequest
from openapi_client.models.tax_report1721_a1_page_response import TaxReport1721A1PageResponse
from openapi_client.models.tax_report1721_a1_response import TaxReport1721A1Response
from openapi_client.models.tax_report1721_vi_detail_response import TaxReport1721VIDetailResponse
from openapi_client.models.tax_report1721_viii_page_response import TaxReport1721VIIIPageResponse
from openapi_client.models.tax_report1721_viii_response import TaxReport1721VIIIResponse
from openapi_client.models.tax_report1721_vii_page_response import TaxReport1721VIIPageResponse
from openapi_client.models.tax_report1721_vii_response import TaxReport1721VIIResponse
from openapi_client.models.tax_report1721_vi_page_response import TaxReport1721VIPageResponse
from openapi_client.models.tax_report1721_vi_response import TaxReport1721VIResponse
from openapi_client.models.temporary_monthly_tax_calculation_simulator_response import TemporaryMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.termination_bpjs_manpower_reason_page_response import TerminationBPJSManpowerReasonPageResponse
from openapi_client.models.termination_bpjs_manpower_reason_response import TerminationBPJSManpowerReasonResponse
from openapi_client.models.termination_entry_request import TerminationEntryRequest
from openapi_client.models.termination_entry_response import TerminationEntryResponse
from openapi_client.models.termination_reason_category_page_response import TerminationReasonCategoryPageResponse
from openapi_client.models.termination_reason_category_response import TerminationReasonCategoryResponse
from openapi_client.models.termination_reason_detail_response import TerminationReasonDetailResponse
from openapi_client.models.termination_reason_page_response import TerminationReasonPageResponse
from openapi_client.models.termination_reason_request import TerminationReasonRequest
from openapi_client.models.termination_reason_response import TerminationReasonResponse
from openapi_client.models.termination_tax_reason_page_response import TerminationTaxReasonPageResponse
from openapi_client.models.termination_tax_reason_response import TerminationTaxReasonResponse
from openapi_client.models.time_allowance_detail_response import TimeAllowanceDetailResponse
from openapi_client.models.time_allowance_details_response import TimeAllowanceDetailsResponse
from openapi_client.models.time_zone_response import TimeZoneResponse
from openapi_client.models.transition_calculation_count_response import TransitionCalculationCountResponse
from openapi_client.models.transition_calculation_details_amount_request import TransitionCalculationDetailsAmountRequest
from openapi_client.models.transition_calculation_details_request import TransitionCalculationDetailsRequest
from openapi_client.models.transition_calculation_employee_salary_template_response import TransitionCalculationEmployeeSalaryTemplateResponse
from openapi_client.models.transition_calculation_response import TransitionCalculationResponse
from openapi_client.models.transition_calculation_salary_template_detail_response import TransitionCalculationSalaryTemplateDetailResponse
from openapi_client.models.transition_time_allowance_detail_response import TransitionTimeAllowanceDetailResponse
from openapi_client.models.unprocessable_content_response import UnprocessableContentResponse
from openapi_client.models.unprocessable_message import UnprocessableMessage
from openapi_client.models.unprocessed_transition_calculation_page_response import UnprocessedTransitionCalculationPageResponse
from openapi_client.models.unprocessed_transition_calculation_response import UnprocessedTransitionCalculationResponse
from openapi_client.models.update_bank_account_configuration_request import UpdateBankAccountConfigurationRequest
from openapi_client.models.user_and_role_response import UserAndRoleResponse
from openapi_client.models.user_page_response import UserPageResponse
from openapi_client.models.user_response import UserResponse
from openapi_client.models.widget_content_response import WidgetContentResponse
from openapi_client.models.widget_page_response import WidgetPageResponse
from openapi_client.models.widget_response import WidgetResponse
from openapi_client.models.workday_configuration_detail_response import WorkdayConfigurationDetailResponse
from openapi_client.models.workflow_activity_page_response import WorkflowActivityPageResponse
from openapi_client.models.workflow_activity_response import WorkflowActivityResponse
from openapi_client.models.workflow_reason_category_page_response import WorkflowReasonCategoryPageResponse
from openapi_client.models.workflow_reason_category_request import WorkflowReasonCategoryRequest
from openapi_client.models.workflow_reason_category_response import WorkflowReasonCategoryResponse
from openapi_client.models.workflow_reason_page_response import WorkflowReasonPageResponse
from openapi_client.models.workflow_reason_request import WorkflowReasonRequest
from openapi_client.models.workflow_reason_response import WorkflowReasonResponse
from openapi_client.models.workflow_template_response import WorkflowTemplateResponse
from openapi_client.models.workgroup_workday_configuration_page_response import WorkgroupWorkdayConfigurationPageResponse
from openapi_client.models.workgroup_workday_configuration_request import WorkgroupWorkdayConfigurationRequest
from openapi_client.models.workgroup_workday_configuration_response import WorkgroupWorkdayConfigurationResponse

