# flake8: noqa

# import apis into api package
from openapi_client.api.analytics_api import AnalyticsApi
from openapi_client.api.anomaly_detection_api import AnomalyDetectionApi
from openapi_client.api.bank_account_configuration_api import BankAccountConfigurationApi
from openapi_client.api.bpjs_healthcare_api import BpjsHealthcareApi
from openapi_client.api.bpjs_manpower_api import BpjsManpowerApi
from openapi_client.api.company_bank_account_api import CompanyBankAccountApi
from openapi_client.api.contact_information_api import ContactInformationApi
from openapi_client.api.custom_table_api import CustomTableApi
from openapi_client.api.custom_table_entry_api import CustomTableEntryApi
from openapi_client.api.editable_salary_preprocess_api import EditableSalaryPreprocessApi
from openapi_client.api.employee_api import EmployeeApi
from openapi_client.api.employee_bank_account_configuration_api import EmployeeBankAccountConfigurationApi
from openapi_client.api.employee_bpjs_membership_api import EmployeeBpjsMembershipApi
from openapi_client.api.employee_detail_api import EmployeeDetailApi
from openapi_client.api.employee_paygroup_api import EmployeePaygroupApi
from openapi_client.api.employee_payment_item_group_sequence_api import EmployeePaymentItemGroupSequenceApi
from openapi_client.api.employee_salary_template_api import EmployeeSalaryTemplateApi
from openapi_client.api.employee_variable_api import EmployeeVariableApi
from openapi_client.api.employment_status_api import EmploymentStatusApi
from openapi_client.api.families_api import FamiliesApi
from openapi_client.api.former_employee_income_api import FormerEmployeeIncomeApi
from openapi_client.api.identity_cards_api import IdentityCardsApi
from openapi_client.api.master_data_api import MasterDataApi
from openapi_client.api.oauth_client_api import OauthClientApi
from openapi_client.api.organization_api import OrganizationApi
from openapi_client.api.paygroup_api import PaygroupApi
from openapi_client.api.payroll_others_api import PayrollOthersApi
from openapi_client.api.payroll_process_snapshot_api import PayrollProcessSnapshotApi
from openapi_client.api.payslip_api import PayslipApi
from openapi_client.api.role_api import RoleApi
from openapi_client.api.salary_calculation_api import SalaryCalculationApi
from openapi_client.api.salary_item_api import SalaryItemApi
from openapi_client.api.salary_payment_api import SalaryPaymentApi
from openapi_client.api.salary_template_api import SalaryTemplateApi
from openapi_client.api.severance_api import SeveranceApi
from openapi_client.api.tax_api import TaxApi
from openapi_client.api.tax_membership_api import TaxMembershipApi
from openapi_client.api.tax_membership_history_api import TaxMembershipHistoryApi
from openapi_client.api.termination_api import TerminationApi
from openapi_client.api.time_management_api import TimeManagementApi
from openapi_client.api.transition_calculation_api import TransitionCalculationApi
from openapi_client.api.user_api import UserApi
from openapi_client.api.widgets_api import WidgetsApi
from openapi_client.api.workflow_api import WorkflowApi

